@@ -1,6 +1,6 @@
 package ETL::Yertl;
 # ABSTRACT: ETL with a Shell
-$ETL::Yertl::VERSION = '0.017';
+$ETL::Yertl::VERSION = '0.018';
 use strict;
 use warnings;
 use base 'Import::Base';
@@ -55,7 +55,7 @@ ETL::Yertl - ETL with a Shell
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 SYNOPSIS
 
@@ -135,7 +135,7 @@ Doug Bell <preaction@cpan.org>
 
 =for stopwords Doug Bell
 
-Doug Bell <doug.bell@baml.com>
+Doug Bell <preaction@users.noreply.github.com>
 
 =head1 COPYRIGHT AND LICENSE
 
