@@ -1,5 +1,6 @@
 package ETL::Yertl::Command::yfrom;
-$ETL::Yertl::Command::yfrom::VERSION = '0.017';
+# ABSTRACT: Read documents from a format like JSON or CSV
+$ETL::Yertl::Command::yfrom::VERSION = '0.018';
 use ETL::Yertl;
 use ETL::Yertl::Format::yaml;
 use Module::Runtime qw( use_module compose_module_name );
@@ -57,11 +58,11 @@ __END__
 
 =head1 NAME
 
-ETL::Yertl::Command::yfrom
+ETL::Yertl::Command::yfrom - Read documents from a format like JSON or CSV
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 AUTHOR
 
