@@ -1,5 +1,6 @@
 package ETL::Yertl::Command::ymask;
-$ETL::Yertl::Command::ymask::VERSION = '0.017';
+# ABSTRACT: Filter documents through applying a mask
+$ETL::Yertl::Command::ymask::VERSION = '0.018';
 use ETL::Yertl;
 use ETL::Yertl::Format::yaml;
 use Data::Partial::Google;
@@ -49,11 +50,11 @@ __END__
 
 =head1 NAME
 
-ETL::Yertl::Command::ymask
+ETL::Yertl::Command::ymask - Filter documents through applying a mask
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 AUTHOR
 
