@@ -1,5 +1,6 @@
 package ETL::Yertl::Command::yq;
-$ETL::Yertl::Command::yq::VERSION = '0.017';
+# ABSTRACT: Filter and construct documents using a mini-language
+$ETL::Yertl::Command::yq::VERSION = '0.018';
 use ETL::Yertl;
 use YAML;
 use boolean qw( :all );
@@ -104,11 +105,11 @@ __END__
 
 =head1 NAME
 
-ETL::Yertl::Command::yq
+ETL::Yertl::Command::yq - Filter and construct documents using a mini-language
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 SYNOPSIS
 
