@@ -1,5 +1,6 @@
 package ETL::Yertl::Command::ysql;
-$ETL::Yertl::Command::ysql::VERSION = '0.017';
+# ABSTRACT: Read and write documents with a SQL database
+$ETL::Yertl::Command::ysql::VERSION = '0.018';
 use ETL::Yertl;
 use Getopt::Long qw( GetOptionsFromArray );
 use ETL::Yertl::Format::yaml;
@@ -40,7 +41,7 @@ sub main {
 
         my $db_key = !$opt{dsn} ? shift @args : undef;
         my @dbi_args = $opt{dsn} ? ( $opt{dsn} ) : dbi_args( $db_key );
-        my $dbh = DBI->connect( @dbi_args );
+        my $dbh = DBI->connect( @dbi_args, { PrintError => 0 } );
 
         my $query = shift @args;
         if ( $db_key ) {
@@ -50,32 +51,39 @@ sub main {
             }
         }
 
-        my $sth = $dbh->prepare( $query );
-        $sth->execute( @args );
+        # Resolve interpolations with placeholders
+        my @fields = $query =~ m/\$(\.[.\w]+)/g;
+        $query =~ s/\$\.[\w.]+/?/g;
 
-        while ( my $doc = $sth->fetchrow_hashref ) {
-            print $out_fmt->write( $doc );
+        my $sth = $dbh->prepare( $query )
+            or die "SQL error in prepare: " . $dbh->errstr . "\n";
+
+        if ( !-t *STDIN ) {
+            my $in_fmt = ETL::Yertl::Format::yaml->new( input => \*STDIN );
+
+            for my $doc ( $in_fmt->read ) {
+                $sth->execute( map { select_doc( $_, $doc ) } @fields )
+                    or die "SQL error in execute: " . $dbh->errstr . "\n";
+                while ( my $doc = $sth->fetchrow_hashref ) {
+                    print $out_fmt->write( $doc );
+                }
+            }
+
+        }
+        else {
+            $sth->execute( @args )
+                or die "SQL error in execute: " . $dbh->errstr . "\n";
+            while ( my $doc = $sth->fetchrow_hashref ) {
+                print $out_fmt->write( $doc );
+            }
         }
 
         return 0;
     }
-    elsif ( $command eq 'write' ) {
-        my @dbi_args = $opt{dsn} ? ( $opt{dsn} ) : dbi_args( shift );
-        my $dbh = DBI->connect( @dbi_args );
-
-        my $query = shift;
-        my @fields = $query =~ m/\$(\.[.\w]+)/g;
-        $query =~ s/\$\.[\w.]+/?/g;
-
-        my $sth = $dbh->prepare( $query );
-
-        my $in_fmt = ETL::Yertl::Format::yaml->new( input => \*STDIN );
-        for my $doc ( $in_fmt->read ) {
-            $sth->execute( map { select_doc( $_, $doc ) } @fields );
-        }
-    }
     elsif ( $command eq 'config' ) {
         my ( $db_key, @args ) = @_;
+        # Allow writing "--dsn" before the DSN
+        unshift @args, $opt{dsn} if $opt{dsn};
 
         if ( !$db_key ) {
             my $out_fmt = ETL::Yertl::Format::yaml->new;
@@ -219,11 +227,11 @@ __END__
 
 =head1 NAME
 
-ETL::Yertl::Command::ysql
+ETL::Yertl::Command::ysql - Read and write documents with a SQL database
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 AUTHOR
 
