@@ -1,5 +1,6 @@
 package ETL::Yertl::Command::yto;
-$ETL::Yertl::Command::yto::VERSION = '0.017';
+# ABSTRACT: Write documents to a format like JSON or CSV
+$ETL::Yertl::Command::yto::VERSION = '0.018';
 use ETL::Yertl;
 use Module::Runtime qw( use_module compose_module_name is_module_spec );
 use ETL::Yertl::Format::yaml;
@@ -60,11 +61,11 @@ __END__
 
 =head1 NAME
 
-ETL::Yertl::Command::yto
+ETL::Yertl::Command::yto - Write documents to a format like JSON or CSV
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 SYNOPSIS
 
